<?php
    /* 
    ============================================================================
    main entry point for normal users. this page decides whether to fetch the
    data from the database or to display the contents of a prerendered file.
    ============================================================================
    Author: Martin Widmann, martin.widmann@ideefix.net
    Version: 1.0
    */

    require("config.php");
    require("db_functions.php");
    require("file_functions.php");

    $id = $_REQUEST["id"];
    
    if ($id == '') {
        echo("Sorry pal, without a valid match I can't show you anything");
        exit();
    }
    
    $updateFile = OUTPUTDIR . "/update_$id";
    $tickerFile = OUTPUTDIR . "/ticker_$id";
    
    $content = "";
    // look for the existance of a file called update_$id. if there is none just
    // load all the info from the ticker_$id fragment and display what's in there.
    // if there have been no changes there's no need to load all the stuff every
    // time
    if (file_exists($updateFile)) {
        
        // delete the update file as only one process should recreate the data
        unlink($updateFile);
        
        // loading the fragments into memory.
        $matchFragment = loadContent(FRAGMENTDIR . '/match.html');
        $infoFragment = loadContent(FRAGMENTDIR . '/info.html');
        $goalFragment = loadContent(FRAGMENTDIR . '/goal.html');
        $penaltyFragment = loadContent(FRAGMENTDIR . '/penalty.html');
        $bodyFragment = loadContent(FRAGMENTDIR . '/body.html');
        
        // loading the data for the match itself
        $sql = "SELECT * FROM liveticker_match WHERE match_id = $id";
        
        if ($conn->query($sql) > 0) {
            
            $row = $conn->resultRows[0];
            $home           = $row->home;
            $home_name      = $row->home_name;
            $away           = $row->away;
            $away_name      = $row->away_name;
            $matchdate      = $row->matchdate;
            $info           = $conn->escape($row->info);
            
            $playtime       = "00:00";
            $homegoal       = 0;
            $awaygoal       = 0;
            
            $tickerContent = "";
            
            $sql = "SELECT * FROM liveticker_entry WHERE match_id = $id ORDER BY playtime asc, entry_id asc";
            if ($conn->query($sql) > 0) {
                
                for ($i = 0; $i < $conn->resultCount; $i++) {
                    $row = $conn->resultRows[$i];
                    
                    $entry_type         = $row->entry_type;
                    $team               = $row->team;
                    $playtime           = $row->playtime;
                    $player1            = $row->player1;
                    $player2            = $row->player2;
                    $player3            = $row->player3;
                    $powerplay          = $row->powerplay;
                    $penalty_time       = $row->penalty_time;
                    $penalty_reason     = $row->penalty_reason;
                    $penalty_extension  = $row->penalty_extension;
                    $info               = $conn->unescape($row->info);
                    
                    $entryValues = array(
                        'playtime' => $playtime,
                        'player1' => $player1,
                        'player2' => $player2,
                        'player3' => $player3,
                        'powerplay' => $powerplay,
                        'penalty_time' => $penalty_time,
                        'penalty_reason' => $penalty_reason,
                        'penalty_extension' => $penalty_extension,
                        'info' => eregi_replace("\n", "<br>", $info)
                    );

                    $teamname = "";
                    if ($team == 0) $teamname = $home_name;
                    if ($team == 1) $teamname = $away_name;
                    
                    if ($entry_type == 0) { // info
                        $entryValues = array(
                            'playtime' => $playtime,
                            'team' => $teamname,
                            'result' => $homegoal . ":" . $awaygoal,
                            'info' => eregi_replace("\n", "<br>", $info)
                        );
                        
                        $tickercontent = replaceFragmentPlaceholders($infoFragment, $entryValues) . $tickercontent;
                    
                    } else if ($entry_type == 1) { // goal
                        
                        if ($team == 0) {
                            $homegoal++;
                        } else if ($team == 1) {
                            $awaygoal++;
                        }
                        
                        $assist = "";
                        if ($player2 != '') {
                            $assist = "($player2";
                            if ($player3 != '') {
                                $assist .= ", $player3";
                            }
                            $assist .= ")";
                        }

                        switch ($powerplay) {
                            case 0: $pp_value = "EQ"; break;
                            case 1: $pp_value = "PP1"; break;
                            case 2: $pp_value = "PP2"; break;
                            case 3: $pp_value = "SH1"; break;
                            case 4: $pp_value = "SH2"; break;
                        }

                        if ($info != '') $info = "<br><br>$info";
                        
                        $entryValues = array(
                            'playtime' => $playtime,
                            'result' => $homegoal . ":" . $awaygoal,
                            'team' => $teamname,
                            'player1' => $player1,
                            'assists' => $assist,
                            'powerplay' => $pp_value,
                            'info' => eregi_replace("\n", "<br>", $info)
                        );

                        $tickercontent = replaceFragmentPlaceholders($goalFragment, $entryValues) . $tickercontent;
                    
                    } else if ($entry_type == 2) { // penalty

                        if ($penalty_time == 0) {
                            $penalty = "";
                            switch ($penalty_extension) {
                                case 0: $penalty .= ' Minuten'; break;
                                case 1: $penalty .= '2 Minuten'; break;
                                case 2: $penalty .= '10 Minuten Disziplinarstrafe'; break;
                                case 3: $penalty .= 'Spieldauerstrafe'; break;
                                case 4: $penalty .= 'Matchstrafe'; break;
                            }
                        } else {
                            $penalty = $penalty_time;
                            switch ($penalty_extension) {
                                case 0: $penalty .= ' Minuten'; break;
                                case 1: $penalty .= '+2 Minuten'; break;
                                case 2: $penalty .= '+10 Minuten Disziplinarstrafe'; break;
                                case 3: $penalty .= ' Minuten + Spieldauer'; break;
                                case 4: $penalty .= ' Minuten + Matchstrafe'; break;
                            }
                        }    
                        
                        if ($info != '') $info = "<br><br>$info";
                        
                        $entryValues = array(
                            'playtime' => $playtime,
                            'result' => $homegoal . ":" . $awaygoal,
                            'player1' => $player1,
                            'team' => $teamname,
                            'penalty' => $penalty,
                            'reason' => $penalty_reason,
                            'info' => eregi_replace("\n", "<br>", $info)
                        );

                        $tickercontent = replaceFragmentPlaceholders($penaltyFragment, $entryValues) . $tickercontent;
                    } 
                }
            }
            
            list ($min, $sec) = split(":", $playtime);
            
            if ($min < 20) {
                $period = "1st";
            } else if ($min < 40) {
                $period = "2nd";
            } else if ($min < 60  || ($min == 60 && $sec == 0)) {
                $period = "3rd";
            } else if (($min == 60 && $sec > 0) || ($min > 60)) {
                $period = "OT";
            }
            
            
            $matchValues = array(
                'home' => $home, 
                'homename' => $home_name,
                'away' => $away, 
                'awayname' => $away_name,
                'matchdate' => $matchdate, 
                'info' => $info, 
                'homegoal' => $homegoal, 
                'awaygoal' => $awaygoal,
                'period' => $period, 
                'playtime' => $playtime);
                
            $matchData = replaceFragmentPlaceholders($matchFragment, $matchValues);    
            
            $bodyValues = array(
                'match' => $matchData,
                'entries' => $tickercontent
            );
            
            $content = replaceFragmentPlaceholders($bodyFragment, $bodyValues);
            
            // write the content to file
            writeContent($tickerFile, $content);
            
        } else {
            echo("Sorry pal, where'd you get this link from? There's no match!");
            exit();
        }
        
        
        
    } else {
        if (!file_exists($tickerFile)) {
            echo("Sorry pal, there's nothing to display for the given Ticker");
            exit();
        }
        $content = loadContent($tickerFile);
        
//        $file = fopen($tickerFile, "r");
//        $content = fread($file, filesize($tickerFile));
//        fclose($file);
    }

    // write the content
    echo $content;


    
    // replaces every occurrance of ${values.KEY} in $fragment with the 
    // value of ${values.KEY} 
    function replaceFragmentPlaceholders($fragment, $values) {
        $replacedContent = $fragment;
        $keys = array_keys($values);
        foreach ($keys as $key) {
            if (preg_match("/\@\{$key\}/", $replacedContent)) {
                $replacedContent = preg_replace("/\@\{$key\}/", $values[$key], $replacedContent);
            }
            
        }
        return $replacedContent;
    }
    

    
?>